@@ -14,9 +14,10 @@ from typing import NamedTuple
 # ########## Classes ###############
 # ##################################
 class PageInformation(NamedTuple):
-    abs_path: Path
-    created: datetime
-    updated: datetime
-    title: str
-    description: str
-    url_full: str
+    abs_path: Path = None
+    created: datetime = None
+    updated: datetime = None
+    title: str = None
+    description: str = None
+    image: str = None
+    url_full: str = None
