@@ -7,6 +7,7 @@
 # standard library
 import logging
 import ssl
+from datetime import date, datetime
 from email.utils import formatdate
 from mimetypes import guess_type
 from pathlib import Path
@@ -35,6 +36,13 @@ REMOTE_REQUEST_HEADERS = {
 }
 
 
+# ############################################################################
+# ########## Globals ###############
+# ##################################
+
+logger = logging.getLogger("mkdocs.mkdocs_rss_plugin")
+
+
 # ############################################################################
 # ########## Classes #############
 # ################################
@@ -83,34 +91,76 @@ class Util:
             url_parts[4] = urlencode(args_dict)
         return urlunparse(url_parts)
 
-    def get_file_dates(self, path: str) -> Tuple[int, int]:
-        """Extract creation and update dates from git log for given file.
+    def get_file_dates(
+        self,
+        in_page: Page,
+        source_date_creation: str = "git",
+        source_date_update: str = "git",
+        meta_datetime_format: str = "%Y-%m-%d %H:%M",
+    ) -> Tuple[int, int]:
+        """Extract creation and update dates from page metadata (yaml frontmatter) or \
+            git log for given file.
 
-        :param str path: path to a tracked file
+        :param in_page: input page to work with
+        :type in_page: Page
+        :param source_date_creation: which source to use (git or meta tag) for creation \
+            date, defaults to "git"
+        :type source_date_creation: str, optional
+        :param source_date_update: which source to use (git or meta tag) for update \
+            date, defaults to "git"
+        :type source_date_update: str, optional
+        :param meta_datetime_format: datetime string format, defaults to "%Y-%m-%d %H:%M"
+        :type meta_datetime_format: str, optional
 
-        :return: (creation date, last commit date)
-        :rtype: tuple of timestamps
+        :return: tuple of timestamps (creation date, last commit date)
+        :rtype: Tuple[int, int]
         """
         # empty vars
         dt_created = dt_updated = None
 
+        # if enabled, try to retrieve dates from page metadata
+        if source_date_creation != "git" and in_page.meta.get(source_date_creation):
+            dt_created = self.get_date_from_meta(
+                date_metatag_value=in_page.meta.get(source_date_creation),
+                meta_datetime_format=meta_datetime_format,
+            )
+            if isinstance(dt_created, str):
+                logger.error(dt_created)
+                dt_created = None
+
+        if source_date_update != "git" and in_page.meta.get(source_date_update):
+            dt_updated = self.get_date_from_meta(
+                date_metatag_value=in_page.meta.get(source_date_creation),
+                meta_datetime_format=meta_datetime_format,
+            )
+            if isinstance(dt_updated, str):
+                logger.error(dt_updated)
+                dt_updated = None
+
         # explore git log
         if self.git_is_valid:
             try:
-                dt_created = self.repo.log(
-                    path, n=1, date="short", format="%at", diff_filter="AR"
-                )
-                dt_updated = self.repo.log(
-                    path,
-                    n=1,
-                    date="short",
-                    format="%at",
-                )
+                # only if dates have not been retrieved from page meta
+                if not dt_created:
+                    dt_created = self.repo.log(
+                        in_page.file.abs_src_path,
+                        n=1,
+                        date="short",
+                        format="%at",
+                        diff_filter="AR",
+                    )
+                if not dt_updated:
+                    dt_updated = self.repo.log(
+                        in_page.file.abs_src_path,
+                        n=1,
+                        date="short",
+                        format="%at",
+                    )
             except GitCommandError as err:
                 logging.warning(
                     "[rss-plugin] Unable to read git logs of '%s'. Is git log readable?"
                     " Falling back to build date. "
-                    " Trace: %s" % (path, err)
+                    " Trace: %s" % (in_page.file.abs_src_path, err)
                 )
             except GitCommandNotFound as err:
                 logging.error(
@@ -129,12 +179,46 @@ class Util:
                 int(dt_updated),
             )
         else:
-            logging.warning("Dates could not be retrieved for page: %s." % path)
+            logging.warning(
+                "[rss-plugin] Dates could not be retrieved for page: %s."
+                % in_page.file.abs_src_path
+            )
             return (
                 get_build_timestamp(),
                 get_build_timestamp(),
             )
 
+    def get_date_from_meta(
+        self, date_metatag_value: str, meta_datetime_format: str
+    ) -> float:
+        """Get date from page.meta handling str with associated datetime format and \
+            date already transformed by MkDocs.
+
+        :param date_metatag_value: value of page.meta.{tag_for_date}
+        :type date_metatag_value: str
+        :param meta_datetime_format: expected format of datetime
+        :type meta_datetime_format: str
+
+        :return: datetime as timestamp
+        :rtype: float
+        """
+        out_date = None
+        try:
+            if isinstance(date_metatag_value, str):
+                out_date = datetime.strptime(date_metatag_value, meta_datetime_format)
+            elif isinstance(date_metatag_value, (date, datetime)):
+                out_date = datetime.combine(date_metatag_value, datetime.min.time())
+            else:
+                return "[rss-plugin] Incompatible date type."
+        except ValueError as err:
+            return "[rss-plugin] Incompatible date found. Trace: {}".format(err)
+        except Exception as err:
+            return "[rss-plugin] Unable to retrieve creation date. Trace: {}".format(
+                err
+            )
+
+        return out_date.timestamp()
+
     def get_description_or_abstract(self, in_page: Page, chars_count: int = 150) -> str:
         """Returns description from page meta. If it doesn't exist, use the \
         {chars_count} first characters from page content (in markdown).
@@ -267,25 +351,52 @@ class Util:
         return img_length
 
     @staticmethod
-    def guess_locale(config: Config) -> str or None:
+    def get_site_url(mkdocs_config: Config) -> str or None:
+        """Extract site URL from MkDocs configuration and enforce the behavior to ensure \
+        returning a str with length > 0 or None. If exists, it adds an ending slash.
+
+        :param mkdocs_config: configuration object
+        :type mkdocs_config: Config
+
+        :return: site url
+        :rtype: str or None
+        """
+        # this method exists because the following line returns an empty string instead of \
+        # None (because the key alwayus exists)
+        defined_site_url = mkdocs_config.get("site_url", None)
+
+        # cases
+        if defined_site_url is None or not len(defined_site_url):
+            # in cas of mkdocs's behavior change
+            site_url = None
+        else:
+            site_url = defined_site_url
+            # handle trailing slash
+            if not site_url.endswith("/"):
+                site_url = site_url + "/"
+
+        return site_url
+
+    @staticmethod
+    def guess_locale(mkdocs_config: Config) -> str or None:
         """Extract language code from MkDocs or Theme configuration.
 
-        :param config: configuration object
-        :type config: Config
+        :param mkdocs_config: configuration object
+        :type mkdocs_config: Config
 
         :return: language code
         :rtype: str or None
         """
         # MkDocs locale settings - might be added in future mkdocs versions
         # see: https://github.com/timvink/mkdocs-git-revision-date-localized-plugin/issues/24
-        if config.get("locale"):
-            return config.get("locale")
+        if mkdocs_config.get("locale"):
+            return mkdocs_config.get("locale")
 
         # Some themes implement a locale or a language setting
-        if "theme" in config and "locale" in config.get("theme"):
-            return config.get("theme")._vars.get("locale")
-        elif "theme" in config and "language" in config.get("theme"):
-            return config.get("theme")._vars.get("language")
+        if "theme" in mkdocs_config and "locale" in mkdocs_config.get("theme"):
+            return mkdocs_config.get("theme")._vars.get("locale")
+        elif "theme" in mkdocs_config and "language" in mkdocs_config.get("theme"):
+            return mkdocs_config.get("theme")._vars.get("language")
         else:
             return None
 
